@@ -7,11 +7,11 @@ test_that("Is discrete should return true", {
 })
 
 test_that("Returns values between 0 and 1", {
-  result <- relief(iris,'Species',c('Sepal.Length'))
+  result <- relief()(iris,'Species',c('Sepal.Length'))
   expect_gte(result, 0)
   expect_lte(result, 1)
 })
 test_that("Names are set", {
-  expect_equal(attr(relief,'name'),"Relief");
-  expect_equal(attr(relief,'shortName'),"relief");
+  expect_equal(attr(relief(),'name'),"Relief");
+  expect_equal(attr(relief(),'shortName'),"relief");
 })
\ No newline at end of file
